var services = angular.module('services', []);
services.service(
		'BPMRolesService', 
		function($http) 
		{
			// Sample roles service which uses HTTP / REST to get roles information from the AMX BPM server
			// This could easily be changed to use the ObjectAPI rather than direct REST
			
			// Setup the base paths for our REST calls
			var bpmUrl = "../../bpm/rest/";
			var apaUrl = "../rest/";
			var selectedRole;
			var roles;
		
			// Allow the user to select a role, when this happens we retrieve the roleModel with all the role settings form the server
			selectRoleInt = function(roleName) {
					var getRoleModelUrl = apaUrl + "roles/v1/model/";										
					getRoleModelUrl = getRoleModelUrl + roleName;
												
					$http.get(getRoleModelUrl)
						.then(function(data) {
							selectedRole = data;										
						}, function(data) {
							alert(data);
						});
			}
			
			return {
				// Get the roles for the logged in user, this involves calling Directory Engine and the Roles Engine
				getRolesForUser: function() {
					// Call the getResource service without passing a GUID - this gives information for the logged in user
					$http.get(bpmUrl + 'orgresource/get/-1')
							.then(function(data) {
								// On sucess call the listRoles method to ensure the latest roles are loaded
								var listRolesUrl = apaUrl + "roles/v1?forceReload=true";
								
								// Build up a list of the groups to which the user belongs ( could also include Positions but not used in this example )
								angular.forEach(data.data.resource[0].group, 
									function(group) 
									{ 
										// List the roles for the supplied targets.  This will get all the roles mapped to the targets ( groups ) supplied
										listRolesUrl = listRolesUrl + "&target=" + group["@guid"];
									}				
								);

								$http.get(listRolesUrl)
									.then(
										// On success select the first role that came back as a default
										// This will trigger the UI to update the components and settings as the selectedRole will change
										function(data) {										
											if (data.data.length > 0)
											{
												roles = data.data;												
												selectRoleInt(data.data[0].name);
											}
											
									}, function(data) {
											alert(data);
								}).catch(function (error) {
									alert(error);
								});
							}, function(data) {
								alert(data);			
					}).catch(function (error) {
						alert(error);
					});
				},
				// Method to get the components for the selected app ( in the selected role )
				getComponentsForApp: function(appName) {
					if (selectedRole)
					{
						return (selectedRole.data.appConfig[appName].components);
					}
				},
				// Method to get the settings for a component in the selected role
				getSettingForComponent: function(appName, componentName, settingName) {
					if (selectedRole)
					{
						var val = selectedRole.data.appConfig[appName].components[componentName].settings.settingsMap[settingName].value;
						return (val);
					}
				},
				// Method to get the roles which have been retrieved from the engine
				getRoles: function() {
					if (selectedRole)
					{
						return (roles);
					}
				},
				// Method to select the specified role, after this the Service will return settings for that role
				selectRole: function(roleName) {
					if (selectedRole)
					{
						selectRoleInt(roleName);
					}
				},
			}
		});